[llvm-branch-commits] [clang-tools-extra] cbf336a - [clangd] Track deprecation of 'member' semantic token type in LSP.

Sam McCall via llvm-branch-commits llvm-branch-commits at lists.llvm.org
Wed Nov 25 12:36:13 PST 2020


Author: Sam McCall
Date: 2020-11-25T21:31:46+01:00
New Revision: cbf336ad76cd619495b213e8364acaccb7a7c0d6

URL: https://github.com/llvm/llvm-project/commit/cbf336ad76cd619495b213e8364acaccb7a7c0d6
DIFF: https://github.com/llvm/llvm-project/commit/cbf336ad76cd619495b213e8364acaccb7a7c0d6.diff

LOG: [clangd] Track deprecation of 'member' semantic token type in LSP.

Added: 
    

Modified: 
    clang-tools-extra/clangd/SemanticHighlighting.cpp

Removed: 
    


################################################################################
diff  --git a/clang-tools-extra/clangd/SemanticHighlighting.cpp b/clang-tools-extra/clangd/SemanticHighlighting.cpp
index 1a78e7a8c0da..44d74f387dd1 100644
--- a/clang-tools-extra/clangd/SemanticHighlighting.cpp
+++ b/clang-tools-extra/clangd/SemanticHighlighting.cpp
@@ -556,12 +556,11 @@ llvm::StringRef toSemanticTokenType(HighlightingKind Kind) {
   case HighlightingKind::Function:
     return "function";
   case HighlightingKind::Method:
-    return "member";
+    return "method";
   case HighlightingKind::StaticMethod:
     // FIXME: better function/member with static modifier?
     return "function";
   case HighlightingKind::Field:
-    // Not "member": https://github.com/clangd/vscode-clangd/issues/105
     return "property";
   case HighlightingKind::Class:
     return "class";
@@ -556,12 +556,11 @@ llvm::StringRef toSemanticTokenType(HighlightingKind Kind) {
   case HighlightingKind::StaticMethod:
-    // FIXME: better function/member with static modifier?
+    // FIXME: better method with static modifier?
     return "function";
   case HighlightingKind::Field:


        


More information about the llvm-branch-commits mailing list